import { world, system } from "@minecraft/server";

// Define the radius around the campfire within which players will heal
const HEALING_RADIUS = 3;
// Define the healing interval in ticks (20 ticks = 1 second)
const HEALING_INTERVAL = 40; // 2 seconds
// Define the amount of health to restore each interval
const HEAL_AMOUNT = 1;

// Function to check if a block is a campfire
function isCampfire(block) {
  return (
    block.typeId === "minecraft:campfire" ||
    block.typeId === "minecraft:soul_campfire"
  );
}

// Function to heal players near campfires
function healPlayersNearCampfires() {
  // Iterate over all players in the world
  for (const player of world.getPlayers()) {
    const playerLocation = player.location;
    const dimension = player.dimension;

    // Check blocks at the player's feet level and directly beneath
    for (let yOffset = -1; yOffset <= 0; yOffset++) {
      for (let x = -HEALING_RADIUS; x <= HEALING_RADIUS; x++) {
        for (let z = -HEALING_RADIUS; z <= HEALING_RADIUS; z++) {
          const blockLocation = {
            x: Math.floor(playerLocation.x) + x,
            y: Math.floor(playerLocation.y) + yOffset,
            z: Math.floor(playerLocation.z) + z,
          };
          const block = dimension.getBlock(blockLocation);

          if (block && isCampfire(block)) {
            // Apply healing effect to the player
            const healthComponent = player.getComponent("minecraft:health");
            if (healthComponent) {
              const currentHealth = healthComponent.current;
              const maxHealth = healthComponent.value;
              // Ensure not to exceed max health
              healthComponent.current = Math.min(
                currentHealth + HEAL_AMOUNT,
                maxHealth
              );
            }
            // Exit inner loops once a campfire is found near the current player
            break;
          }
        }
      }
    }
  }
}

// Schedule the healing function to run at the defined interval
system.runInterval(healPlayersNearCampfires, HEALING_INTERVAL);